
{-# LANGUAGE EmptyDataDecls #-}
module OpenCascade.StlAPI.Types 
( Writer
, Reader
) where

data Writer
data Reader